@@ -5,10 +5,10 @@ module Rouge
   module Lexers
     class TOML < RegexLexer
       title "TOML"
-      desc 'the TOML configuration format (https://github.com/mojombo/toml)'
+      desc 'the TOML configuration format (https://github.com/toml-lang/toml)'
       tag 'toml'
 
-      filenames '*.toml', 'Pipfile'
+      filenames '*.toml', 'Pipfile', 'poetry.lock'
       mimetypes 'text/x-toml'
 
       # bare keys and quoted keys
@@ -20,27 +20,16 @@ module Rouge
         rule %r/(true|false)/, Keyword::Constant
 
         rule %r/(#{identifier})(\s*)(=)(\s*)(\{)/ do
-          groups Name::Namespace, Text, Operator, Text, Punctuation
+          groups Name::Property, Text, Operator, Text, Punctuation
           push :inline
         end
-
-        rule %r/(?<!=)\s*\[[\S]+\]/, Name::Namespace
-
-        rule %r/\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}Z/, Literal::Date
-
-        rule %r/[+-]?\d+(?:_\d+)*\.\d+(?:_\d+)*(?:[eE][+-]?\d+(?:_\d+)*)?/, Num::Float
-        rule %r/[+-]?\d+(?:_\d+)*[eE][+-]?\d+(?:_\d+)*/, Num::Float
-        rule %r/[+-]?(?:nan|inf)/, Num::Float
-
-        rule %r/0x\h+(?:_\h+)*/, Num::Hex
-        rule %r/0o[0-7]+(?:_[0-7]+)*/, Num::Oct
-        rule %r/0b[01]+(?:_[01]+)*/, Num::Bin
-        rule %r/[+-]?\d+(?:_\d+)*/, Num::Integer
       end
 
       state :root do
         mixin :basic
 
+        rule %r/(?<!=)\s*\[.*?\]+/, Name::Namespace
+
         rule %r/(#{identifier})(\s*)(=)/ do
           groups Name::Property, Text, Punctuation
           push :value
@@ -59,6 +48,18 @@ module Rouge
           groups Name::Property, Text, Punctuation
         end
 
+        rule %r/\d{4}-\d{2}-\d{2}(?:[Tt ]\d{2}:\d{2}:\d{2}(?:[Zz]|[+-]\d{2}:\d{2})?)?/, Literal::Date
+        rule %r/\d{2}:\d{2}:\d{2}/, Literal::Date
+
+        rule %r/[+-]?\d+(?:_\d+)*\.\d+(?:_\d+)*(?:[eE][+-]?\d+(?:_\d+)*)?/, Num::Float
+        rule %r/[+-]?\d+(?:_\d+)*[eE][+-]?\d+(?:_\d+)*/, Num::Float
+        rule %r/[+-]?(?:nan|inf)/, Num::Float
+
+        rule %r/0x\h+(?:_\h+)*/, Num::Hex
+        rule %r/0o[0-7]+(?:_[0-7]+)*/, Num::Oct
+        rule %r/0b[01]+(?:_[01]+)*/, Num::Bin
+        rule %r/[+-]?\d+(?:_\d+)*/, Num::Integer
+
         rule %r/"""/, Str, :mdq
         rule %r/"/, Str, :dq
         rule %r/'''/, Str, :msq
